/* 
 * Copyright (C) 2008 Laird Breyer
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Author:   Laird Breyer <laird@lbreyer.com>
 */

#ifndef BOXLIST_H
#define BOXLIST_H

#include "common.h"
#include "imagebuffer.h"

#include <wctype.h>
#include <wchar.h>

#define SYMLEN_UTF8 2
#define SYMLEN (SYMLEN_UTF8 * 4)

typedef struct {
  /* symbol is stored in multibyte format with trailing NUL */
  byte_t symbol[SYMLEN+1];
  unsigned int left;
  unsigned int top;
  unsigned int right;
  unsigned int bottom;
} box_t;

typedef struct {
  box_t *items;
  size_t isize;
  unsigned int count;
} boxlist_t;

void clear_box(box_t *b);

bool_t create_boxlist(boxlist_t *p);
bool_t free_boxlist(boxlist_t *p);

bool_t append_boxlist(boxlist_t *bl, box_t *b);
bool_t insert_boxlist(boxlist_t *bl, box_t *b, int pos);
bool_t remove_boxlist(boxlist_t *p, int pos);

bool_t render_boxlist(boxlist_t *bl, imagebuffer_t *ib, int plane);

#endif
